pub struct WongWangUnit {}Expand description
Four dynamic states of one reduced Wong-Wang decision circuit.
Fields
s1: f64s2: f64noise1: f64noise2: f64tau_s: f64tau_ampa: f64gamma: f64j_n: f64j_cross: f64i_0: f64sigma: f64dt: f64rng: Xoshiro256PlusPlusImplementations
Sourceimpl WongWangUnit
impl WongWangUnit
Sourcepub fn new(seed: u64) -> Self
pub fn new(seed: u64) -> Self
Construct the published parameter set with a reproducible RNG stream.
Sourcepub fn with_parameters(
s1: f64,
s2: f64,
noise1: f64,
noise2: f64,
tau_s: f64,
tau_ampa: f64,
gamma: f64,
j_n: f64,
j_cross: f64,
i_0: f64,
sigma: f64,
dt: f64,
seed: u64,
) -> Result<Self, String>
pub fn with_parameters( s1: f64, s2: f64, noise1: f64, noise2: f64, tau_s: f64, tau_ampa: f64, gamma: f64, j_n: f64, j_cross: f64, i_0: f64, sigma: f64, dt: f64, seed: u64, ) -> Result<Self, String>
Construct one configured state while retaining the supplied RNG seed.
fn validate(&self) -> Result<(), String>
fn phi(i_syn: f64) -> Result<f64, String>
Sourcepub fn step_with_gaussian_samples(
&mut self,
stim1: f64,
stim2: f64,
xi1: f64,
xi2: f64,
) -> Result<(f64, f64), String>
pub fn step_with_gaussian_samples( &mut self, stim1: f64, stim2: f64, xi1: f64, xi2: f64, ) -> Result<(f64, f64), String>
Advance one Euler/OU update from externally supplied normal samples.
Sourcepub fn step(&mut self, stim1: f64, stim2: f64) -> Result<(f64, f64), String>
pub fn step(&mut self, stim1: f64, stim2: f64) -> Result<(f64, f64), String>
Advance one stochastic update using the internal seeded RNG.
fn randn(&mut self) -> f64